@@ -21,8 +21,9 @@ if latex_available:
 else:
     plt.rc("text", usetex=False)
 
-
-colors = ["#029386", "#C875C4", "#E50000", "blue", "purple", "orange"]
+# teal = (0, 100 / 255, 140 / 255)
+teal = "teal"
+colors = [teal, "#C875C4", "#E50000", "blue", "purple", "orange"]
 # colors = np.random.permutation(colors)
 plt.rcParams["axes.prop_cycle"] = plt.cycler(color=colors)
 
@@ -236,7 +237,13 @@ def savefig(dirname, fname):
     return None
 
 
-def plot_polygon(*points, ax=None, color="teal", alpha=0.1, show_vertices=False):
+def plot_polygon(
+    *points,
+    ax=None,
+    color=(0, 100 / 225, 140 / 255),
+    alpha=0.1,
+    show_vertices=False,
+):
     points = [*points]
     points.append(points[0])
     if ax is None:
